.. image:: https://travis-ci.org/asphalt-framework/asphalt.svg?branch=master
  :target: https://travis-ci.org/asphalt-framework/asphalt
  :alt: Build Status
.. image:: https://coveralls.io/repos/asphalt-framework/asphalt/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/asphalt-framework/asphalt?branch=master
  :alt: Code Coverage
.. image:: https://codeclimate.com/github/asphalt-framework/asphalt/badges/gpa.svg
  :target: https://codeclimate.com/github/asphalt-framework/asphalt
  :alt: Code Climate

Asphalt is a microframework for network oriented applications.

It consists of the core (this) and an ecosystem of high level components that offer additional
functionality, often by integrating third party libraries. Asphalt is unique in that it allows
developers to use both coroutine-based (asynchronous) and traditional blocking programming styles
in the same application and every API provided by any Asphalt component supports both approaches,
nearly transparently to the developer. The whole Asphalt ecosystem also follows
`semantic versioning`_, allowing for safe upgrades.

Asphalt uses the standard library `asyncio`_ module and requires Python 3.4 or later.


Project links
-------------

* `Documentation`_
* `Help and support`_
* `Source code`_
* `Issue tracker`_


.. _semantic versioning: http://semver.org/
.. _asyncio: https://docs.python.org/3/library/asyncio.html
.. _Documentation: http://asphalt.readthedocs.org/en/latest/
.. _Help and support: https://github.com/asphalt-framework/asphalt/wiki/Help-and-support
.. _Source code: https://github.com/asphalt-framework/asphalt
.. _Issue tracker: https://github.com/asphalt-framework/asphalt/issues
